Module: Spinebox::Compiler
- Defined in:
- lib/spinebox/compiler.rb
Class Method Summary collapse
-
.compile ⇒ Object
Compiles the assets and the views into the public folder.
Class Method Details
.compile ⇒ Object
Compiles the assets and the views into the public folder
7 8 9 10 11 12 13 14 |
# File 'lib/spinebox/compiler.rb', line 7 def self.compile Spinebox.config.concatenate = true create_directories compile_javascripts compile_stylesheets compile_views copy_images end |